@@ -1,9 +1,10 @@
 from os import name, system
 from time import sleep
-from typing import Dict, Set, Tuple
+from typing import Dict, Optional, Set, Tuple
 
-from .base import BaseTuringMachine
-from .tape import Direction, Tape
+from .base import BaseTuringMachine, MAX_STEPS_ERROR_MSG
+from .tape import Direction, Tape, START_SYMBOL
+from ._helpers import dtm_config_to_md, clear_console, close_file
 
 DTMRule = Tuple[str, str, Direction]
 DTMRules = Dict[str, DTMRule]
@@ -11,7 +12,9 @@ DTMTransitions = Dict[str, DTMRules]
 
 
 class DTM(BaseTuringMachine):
-    """Represents a DETERMINISTIC Turing Machine"""
+    """
+    Represents a Deterministic Turing Machine
+    """
 
     def __init__(
         self,
@@ -19,57 +22,67 @@ class DTM(BaseTuringMachine):
         input_alphabet: Set[str],
         acc_states: Set[str],
         rej_states: Set[str] = set(),
-        transition_function: DTMTransitions = None,
+        transitions: DTMTransitions = None,
         tape: Tape = Tape(),
         initial_state: str = "init",
-        start_symbol: str = ">",
-        empty_symbol: str = "",
+        start_symbol: str = START_SYMBOL,
     ) -> None:
-        if transition_function is None:
-            transition_function = {}
+        if transitions is None:
+            transitions = {}
+
         super().__init__(
             states,
+            input_alphabet,
             acc_states,
             rej_states,
             initial_state,
             start_symbol,
-            empty_symbol,
         )
-        self.input_alphabet = input_alphabet
-        self.transition_function = transition_function
+        self.transitions = transitions
         self.tape = tape
 
-    def get_transition(self, state: str, read: str) -> DTMRule:
-        return self.transition_function.get(state, {}).get(read, None)
+    def get_transition(self, state: str, read: str) -> Optional[DTMRule]:
+        """
+        Gets the transition based on the provided state and read symbol.
 
-    def remove_state(self, state: str) -> bool:
-        if not super().remove_state(state):
-            return False
+        Args:
+            state (str): Current state of the DTM.
+            read (str): Symbol read by the tape head.
 
-        for state in self.transition_function:
-            if state in self.transition_function.keys():
-                del self.transition_function[state]
+        Returns:
+            DTMRule: Transition based on the provided parms if exists, None otherwise.
+        """
+        return self.transitions.get(state, {}).get(read, None)
 
-            for read in self.transition_function[state]:
-                next_s, _, _ = self.transition_function[state][read]
-                if next_s == state:
-                    del self.transition_function[state][read]
+    def write_to_tape(self, input_str: str) -> None:
+        """
+        Writes the provided string on the tape.
 
-        return True
+        Args:
+            input_str (str): String to be written on the tape.
+        """
+        self.tape.write(self.start_symbol + input_str)
+
+    def clear_tape(self) -> None:
+        """
+        Clears the contents of the tape.
+        """
+        self.tape.clear()
 
     def simulate(
         self,
         to_console: bool = True,
         to_file: bool = False,
-        path: str = "simulation.txt",
+        path: str = "simulation.md",
         delay: float = 0.5,
     ) -> bool:
-        """Simulates the machine on its current tape configuration.
+        """
+        Simulates the machine on its current tape configuration.
 
         Args:
             to_console (bool, optional): Set to False if you only want to see the result. Defaults to True.
             to_file (bool, optional): Set to True if you want to save every step to the file. Defaults to False.
-            path (str, optional): Path to the file with the step history. Defaults to "simulation.txt".
+            path (str, optional): Path to the .md file with the step history. Defaults to "simulation.md".
             delay (float, optional): The delay (s) between each step when printing to console. Defaults to 0.5.
 
         Returns:
@@ -78,13 +91,6 @@ class DTM(BaseTuringMachine):
         state: str = self.initial_state
         steps: int = 1
         output_file = None
-        step_separator = f"\n{'=' * 40}\n\n"
-
-        def clear_console() -> None:
-            if name == "posix":
-                system("clear")
-            else:
-                system("cls")
 
         def get_rule_string() -> str:
             row = self.get_transition(state, self.tape.current.value)
@@ -93,39 +99,32 @@ class DTM(BaseTuringMachine):
 
             return f"{step_index}. ({next_step}) -> {row}\n"
 
-        def print_automaton_state() -> None:
+        def print_machine_configuration() -> None:
             rule_str = get_rule_string()
 
             if output_file:
-                output_file.write(rule_str)
-                output_file.write(repr(self.tape))
-                output_file.write(step_separator)
+                output_file.write(dtm_config_to_md(self.tape, rule_str))
 
             if to_console:
                 clear_console()
-                print(rule_str, "\n", self.tape)
-
+                print(f"{rule_str}\n{self.tape}")
                 sleep(delay)
 
-        def close():
-            print_automaton_state()
-
-            if output_file:
-                output_file.close()
-
+        # the simulation itself starts here
         if to_file:
             output_file = open(path, "w")
 
-        while steps <= self.max_steps:
-            print_automaton_state()
+        while steps <= (self.max_steps + 1):
+            print_machine_configuration()
+
             if state in self.acc_states:
-                close()
+                close_file(output_file)
                 return True
 
             rule = self.get_transition(state, self.tape.current.value)
 
             if not rule or rule[0] in self.rej_states:
-                close()
+                close_file()
                 return False
 
             steps += 1
@@ -133,12 +132,8 @@ class DTM(BaseTuringMachine):
             self.tape.write_symbol(write)
             self.tape.move(direction)
 
-        close()
-
-        print(f"Exceeded the maximum allowed steps. ({self.max_steps})")
-        print(
-            "You change the default value by setting the 'max_steps' property of this automaton."
-        )
+        close_file()
+        print(MAX_STEPS_ERROR_MSG.format(self.max_steps))
 
         return False
 
